@@ -114,9 +114,15 @@ int HTTP_HeadersExists(char *cpBuf)
 {
     char *cp1;
     char *cp2;
+    char *cp2a;
     char *cp3;
 
-    if ((cp2 = strstr(cpBuf, "\n\n")) != NULL) {
+    cp2 = NULL;
+    if ((cp2a = strstr(cpBuf, "\n\n")) != NULL)
+        cp2 = cp2a;
+    if ((cp2a = strstr(cpBuf, "\r\n\r\n")) != NULL && (cp2 == NULL || cp2a < cp2))
+        cp2 = cp2a;
+    if (cp2 != NULL) {
         for (cp1 = cpBuf; cp1 < cp2-1; ) {
             cp3 = strchr(cp1, '\n');
             if (!HTTP_IsHeaderLine(cp1, cp3))
@@ -137,11 +143,17 @@ int HTTP_HeaderLineExists(char *cpBuf, char *name)
 {
     char *cp1;
     char *cp2;
+    char *cp2a;
     char *cp3;
     int n;
 
     n = strlen(name);
-    if ((cp2 = strstr(cpBuf, "\n\n")) != NULL) {
+    cp2 = NULL;
+    if ((cp2a = strstr(cpBuf, "\n\n")) != NULL)
+        cp2 = cp2a;
+    if ((cp2a = strstr(cpBuf, "\r\n\r\n")) != NULL && (cp2 == NULL || cp2a < cp2))
+        cp2 = cp2a;
+    if (cp2 != NULL) {
         for (cp1 = cpBuf; cp1 < cp2-1; ) {
             cp3 = strchr(cp1, '\n');
             if (HTTP_IsHeaderLine(cp1, cp3) && cp3-cp1 > n+1)
