@@ -354,6 +354,7 @@ int main(int argc, char **argv, char **env)
     char *cpCGIgi;
     char *cpCGIpt;
     char *cpCGIqs;
+    int fCGIqsEqualChar;
 
     /*  first step: our process initialisation */
     myinit();
@@ -477,27 +478,37 @@ int main(int argc, char **argv, char **env)
         cpCGIpt = "";
     if ((cpCGIqs = getenv("QUERY_STRING")) == NULL)
         cpCGIqs = "";
+    fCGIqsEqualChar = FALSE;
+    if (cpCGIqs != NULL && strchr(cpCGIqs, '=') != NULL)
+        fCGIqsEqualChar = TRUE;
 
-    if (cpCGIgi[0] != NUL &&
-        cpCGIpt[0] != NUL &&
-        (optind == argc || 
-         (optind == argc-1 && 
-          strcmp(argv[optind], cpCGIqs) == 0) ) ) {
-        /*
-        **  Server-Side-Scripting-Language:
-        ** 
-        **  Request:
-        **      /url/to/nph-eperl/url/to/script.phtml[?query-string]
-        **  Environment:
-        **      GATEWAY_INTERFACE=CGI/1.1
-        **      SCRIPT_NAME=/url/to/nph-eperl
-        **      SCRIPT_FILENAME=/path/to/nph-eperl
-        **      PATH_INFO=/url/to/script.phtml
-        **      PATH_TRANSLATED=/path/to/script.phtml
-        **      QUERY_STRING=query-string
-        **      a) optind=argc 
-        **      b) optind=argc-1, argv[optind]=query-string
-        */
+    /*
+     *  Server-Side-Scripting-Language:
+     * 
+     *  Request:
+     *      /url/to/nph-eperl/url/to/script.phtml[?query-string]
+     *  Environment:
+     *      GATEWAY_INTERFACE=CGI/1.1
+     *      SCRIPT_NAME=/url/to/nph-eperl
+     *      SCRIPT_FILENAME=/path/to/nph-eperl
+     *      PATH_INFO=/url/to/script.phtml
+     *      PATH_TRANSLATED=/path/to/script.phtml
+     *      a) QUERY_STRING=""
+     *         optind=argc
+     *      b) QUERY_STRING=query-string (containing "=" char)
+     *         optind=argc 
+     *      c) QUERY_STRING=query-string (containing NO "=" char)
+     *         optind=argc-1
+     *         argv[optind]=query-string
+     */
+    if (   cpCGIgi[0] != NUL 
+        && cpCGIpt[0] != NUL
+        && (   (   optind == argc
+                && (   cpCGIqs[0] == NUL 
+                    || fCGIqsEqualChar      ) ) 
+            || (   optind == argc-1 
+                && !fCGIqsEqualChar 
+                && stringEQ(argv[optind], cpCGIqs) )      ) ) {
         
         if (strncasecmp(cpCGIgi, "CGI/1", 5) != 0) {
             fprintf(stderr, "ePerl:Error: Unknown gateway interface: NOT CGI/1.x\n");
@@ -525,34 +536,39 @@ int main(int argc, char **argv, char **env)
         }
 
         /* set the command line for ``ps'' output */
-        sprintf(ca, "%s %s [%sCGI]", argv[0], source, mode == MODE_NPHCGI ? "NPH-" : "");
+        sprintf(ca, "%s %s [%sCGI/SSSL]", argv[0], source, mode == MODE_NPHCGI ? "NPH-" : "");
         argv[0] = strdup(ca);
     }
-
-    else if (cpCGIgi[0] != NUL &&
-             ((optind == argc-1 && 
-               cpCGIqs[0] == NUL  ) ||
-              (optind == argc-2 && 
-               strcmp(argv[optind+1], cpCGIqs) == 0) ) ) {
-        /*
-        **
-        **  Stand-Alone inside Webserver environment:
-        **
-        **  Request:
-        **      /url/to/script.cgi[/path-info][?query-string]
-        **      [script.cgi has shebang #!/path/to/eperl]
-        **  Environment:
-        **      GATEWAY_INTERFACE=CGI/1.1
-        **      SCRIPT_NAME=/url/to/script.cgi
-        **      SCRIPT_FILENAME=/path/to/script.cgi
-        **      PATH_INFO=/path-info
-        **      PATH_TRANSLATED=/path/to/docroot/path-info
-        **      QUERY_STRING=query-string
-        **      a) optind=argc-1, argv[optind]=/path/to/script.cgi
-        **      b) optind=argc-2, argv[optind]=/path/to/script.cgi
-        **                        argv[optind+1]=query-string
-        **
-        */
+    /*
+     *  Stand-Alone inside Webserver environment:
+     *
+     *  Request:
+     *      /url/to/script.cgi[/path-info][?query-string]
+     *      [script.cgi has shebang #!/path/to/eperl]
+     *  Environment:
+     *      GATEWAY_INTERFACE=CGI/1.1
+     *      SCRIPT_NAME=/url/to/script.cgi
+     *      SCRIPT_FILENAME=/path/to/script.cgi
+     *      PATH_INFO=/path-info
+     *      PATH_TRANSLATED=/path/to/docroot/path-info
+     *      a) QUERY_STRING=""
+     *         optind=argc-1
+     *         argv[optind]=/path/to/script.cgi
+     *      b) QUERY_STRING=query-string (containing "=" char)
+     *         optind=argc-1
+     *         argv[optind]=/path/to/script.cgi
+     *      c) QUERY_STRING=query-string (containing NO "=" char)
+     *         optind=argc-2
+     *         argv[optind]=/path/to/script.cgi
+     *         argv[optind+1]=query-string
+     */
+    else if (   cpCGIgi[0] != NUL
+             && ( (   optind == argc-1 
+                   && (   cpCGIqs[0] == NUL 
+                       || fCGIqsEqualChar      ) ) ||
+                  (   optind == argc-2 
+                   && !fCGIqsEqualChar 
+                   && stringEQ(argv[optind+1], cpCGIqs)) ) ) {
 
         if (strncasecmp(cpCGIgi, "CGI/1", 5) != 0) {
             fprintf(stderr, "ePerl:Error: Unknown gateway interface: NOT CGI/1.x\n");
@@ -580,30 +596,28 @@ int main(int argc, char **argv, char **env)
         }
 
         /* set the command line for ``ps'' output */
-        sprintf(ca, "%s %s [%sCGI]", argv[0], source, mode == MODE_NPHCGI ? "NPH-" : "");
+        sprintf(ca, "%s %s [%sCGI/stand-alone]", argv[0], source, mode == MODE_NPHCGI ? "NPH-" : "");
         argv[0] = strdup(ca);
     }
-
-    else if (cpCGIgi[0] == NUL &&
-             cpCGIpt[0] == NUL &&
-             cpCGIqs[0] == NUL &&
-             optind == argc-1    ) {
-        /*
-        **
-        **  Stand-Alone outside Webserver environment:
-        **
-        **  Request:
-        **      eperl script
-        **  Environment:
-        **      GATEWAY_INTERFACE=<empty>
-        **      SCRIPT_NAME=<empty>
-        **      SCRIPT_FILENAME=<empty>
-        **      PATH_INFO=<empty>
-        **      PATH_TRANSLATED=<empty>
-        **      QUERY_STRING=<empty>
-        **      optind=argc-1, argv[optind]=script
-        **
-        */
+    /*
+     *  Stand-Alone outside Webserver environment:
+     *
+     *  Request:
+     *      eperl script
+     *  Environment:
+     *      GATEWAY_INTERFACE=""
+     *      SCRIPT_NAME=""
+     *      SCRIPT_FILENAME=""
+     *      PATH_INFO=""
+     *      PATH_TRANSLATED=""
+     *      QUERY_STRING=""
+     *      optind=argc-1
+     *      argv[optind]=script
+     */
+    else if (   cpCGIgi[0] == NUL 
+             && cpCGIpt[0] == NUL
+             && cpCGIqs[0] == NUL 
+             && optind == argc-1  ) {
 
         /*  stand-alone filter, source as argument:
             either manually on the console or via shebang */
@@ -611,7 +625,7 @@ int main(int argc, char **argv, char **env)
         mode   = (mode == MODE_UNKNOWN ? MODE_FILTER : mode);
 
         /*  provide flexibility by recognizing "-" for stdin */
-        if (strcmp(source, "-") == 0) {
+        if (stringEQ(source, "-")) {
             /* store stdin to tmpfile */
             source = mytmpfile("ePerl.stdin");
             if ((fp = fopen(source, "w")) == NULL) {
@@ -627,9 +641,10 @@ int main(int argc, char **argv, char **env)
             keepcwd = TRUE;
         }
     }
-
+    /* 
+     *   Any other calling environment is an error...
+     */
     else {
-        /* else we are used in a wrong way... */
         fprintf(stderr, "ePerl:Error: Missing required file to process\n");
         fprintf(stderr, "ePerl:Error: Use either a filename, `-' for STDIN or PATH_TRANSLATED.\n");
         fprintf(stderr, "Try `%s --help' for more information.\n", progname);
@@ -656,11 +671,11 @@ int main(int argc, char **argv, char **env)
 
     /* the built-in GIF images */
     if ((mode == MODE_CGI || mode == MODE_NPHCGI) && (cp = getenv("PATH_INFO")) != NULL) { 
-        if (strcmp(cp, "/logo.gif") == 0) {
+        if (stringEQ(cp, "/logo.gif")) {
             give_img_logo();
             myexit(0);
         }
-        else if (strcmp(cp, "/powered.gif") == 0) {
+        else if (stringEQ(cp, "/powered.gif")) {
             give_img_powered();
             myexit(0);
         }
@@ -706,7 +721,7 @@ int main(int argc, char **argv, char **env)
             n = strlen(source);
             for (i = 0; allowed_file_ext[i] != NULL; i++) {
                 k = strlen(allowed_file_ext[i]);
-                if (strcmp(source+n-k, allowed_file_ext[i]) == 0) 
+                if (stringEQ(source+n-k, allowed_file_ext[i])) 
                     allow = TRUE;
             }
             if (!allow) {
@@ -762,7 +777,7 @@ int main(int argc, char **argv, char **env)
                             pw2 = getpwuid(atoi(allowed_caller_uid[i]));
                         else
                             pw2 = getpwnam(allowed_caller_uid[i]);
-                        if (strcmp(pw->pw_name, pw2->pw_name) == 0) {
+                        if (stringEQ(pw->pw_name, pw2->pw_name)) {
                             allow = TRUE;
                             break;
                         }
@@ -926,7 +941,7 @@ int main(int argc, char **argv, char **env)
         if ((cpHost = getenv("SERVER_NAME")) == NULL)
             cpHost = "localhost";
         cpPort = getenv("SERVER_PORT");
-        if (strcmp(cpPort, "80") == 0)
+        if (stringEQ(cpPort, "80"))
             cpPort = NULL;
         sprintf(ca, "http://%s%s%s%s", 
                 cpHost, cpPort != NULL ? ":" : "", cpPort != NULL ? cpPort : "", cpPath);
@@ -1179,8 +1194,8 @@ int main(int argc, char **argv, char **env)
     /* now when the request was not a HEAD request we create the output */
     cp = getenv("REQUEST_METHOD");
     if (! ((mode == MODE_CGI || mode == MODE_NPHCGI) &&
-           cp != NULL && strcmp(cp, "HEAD") == 0)) {
-        if (outputfile != NULL && strcmp(outputfile, "-") != 0) {
+           cp != NULL && stringEQ(cp, "HEAD"))) {
+        if (outputfile != NULL && stringNE(outputfile, "-")) {
             /* if we remembered current working dir, restore it now */
             if (mode == MODE_FILTER && cwd[0] != NUL)
                 chdir(cwd);
