@@ -66,7 +66,11 @@ void Perl5_XSInit(void)
 */
 void Perl5_ForceUnbufferedStdout(void)
 {
+#if AC_perl_vnum < 500476
     IoFLAGS(GvIOp(defoutgv)) |= IOf_FLUSH; /* $|=1 */
+#else
+    IoFLAGS(GvIOp(PL_defoutgv)) |= IOf_FLUSH; /* $|=1 */
+#endif
     return;
 }
 
