@@ -15,18 +15,18 @@
 **
 **  ======================================================================
 **
-**  Copyright (c) 1996,1997 Ralf S. Engelschall, All rights reserved.
+**  Copyright (c) 1996,1997,1998 Ralf S. Engelschall <rse@engelschall.com>
 **
 **  This program is free software; it may be redistributed and/or modified
 **  only under the terms of either the Artistic License or the GNU General
 **  Public License, which may be found in the ePerl source distribution.
 **  Look at the files ARTISTIC and COPYING or run ``eperl -l'' to receive
-**  a builtin copy of both license files.
+**  a built-in copy of both license files.
 **
 **  This program is distributed in the hope that it will be useful, but
 **  WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either the
-**  GNU General Public License or the Artistic License for more details.
+**  Artistic License or the GNU General Public License for more details.
 **
 **  ======================================================================
 **
@@ -36,9 +36,18 @@
 #define EPERL_SECURITY_H 1
 
 
-/* General security for CGI modes */
+/*
+ * General security for CGI modes
+ */
 #define CGI_NEEDS_ALLOWED_FILE_EXT       TRUE
+#define LIST_OF_ALLOWED_FILE_EXT         { ".html", ".phtml", ".eperl", ".ephtml", ".epl", ".pl", ".cgi", NULL }
 
+/* 
+ * Perl security 
+ * (BE CAREFUL HERE, THIS CAN MAKE YOUR LIVE HARD!) 
+ */
+#define CGI_MODES_FORCE_TAINTING         FALSE
+#define CGI_MODES_FORCE_WARNINGS         FALSE
 
 /*
  * SetUID security checks for CGI modes:
@@ -49,11 +58,8 @@
 #define SETUID_NEEDS_VALID_OWNER_UID     TRUE
 #define SETUID_NEEDS_VALID_OWNER_GID     TRUE
 #define SETUID_NEEDS_BELOW_OWNER_HOME    TRUE
-
-#define LIST_OF_ALLOWED_FILE_EXT         { ".html", ".phtml", ".ephtml", ".epl", ".pl", ".cgi", NULL }
 #define LIST_OF_ALLOWED_CALLER_UID       { "nobody", "root", NULL }
 
-
 /* 
  * Action when a SetUID security check failed.
  *
