@@ -51,7 +51,7 @@ use File::Basename qw(dirname);
 use Parse::ePerl;
 
 #   private version number
-$VERSION = do { my @v=("2.2.13"=~/\d+/g); sprintf "%d."."%02d"x$#v,@v }; 
+$VERSION = do { my @v=("2.2.14"=~/\d+/g); sprintf "%d."."%02d"x$#v,@v }; 
 
 #   globals
 $nDone  = 0;
@@ -370,11 +370,13 @@ Apache::ePerl - Fast emulated Embedded Perl (ePerl) facility
    #   Apache's httpd.conf file
    #   mandatory: activation of Apache::ePerl
    PerlModule Apache::ePerl
-   <Files ~ "/root/of/webmaster/area/.+\.iphtml$">
-       Options     +ExecCGI
-       SetHandler  perl-script
-       PerlHandler Apache::ePerl
-   </Files>
+   <Directory /root/of/webmaster/area>
+       <Files *.iphtml>
+           Options     +ExecCGI
+           SetHandler  perl-script
+           PerlHandler Apache::ePerl
+       </Files>
+   </Directory>
    #   optional: configuration of Apache::ePerl
    <Perl>
    $Apache::ePerl::Config->{'BeginDelimiter'}  = '<?';
@@ -427,12 +429,30 @@ Second, you have to add the following config snippet to Apache's F<httpd.conf>
 file:
 
    PerlModule Apache::ePerl
-   <Files ~ "/root/of/webmaster/area/.+\.iphtml$">
-       Options     +ExecCGI
+   <Directory /root/of/webmaster/area>
+       <Files *.iphtml>
+           Options     +ExecCGI
+           SetHandler  perl-script
+           PerlHandler Apache::ePerl
+       </Files>
+   </Directory>
+
+This forces all files under the directory /root/of/webmaster/area/ with
+extension .iphtml to be processed by the Apache::ePerl::handler function which
+emulates the runtime behavior of the stand-alone "eperl" program (when run as
+a SSSL) up to 90%.  
+
+If you're not paranoid about security (for instance driving a stand-alone
+webserver without user accounts) you can also just use
+
+   PerlModule Apache::ePerl
+   <Files *.iphtml>
        SetHandler  perl-script
        PerlHandler Apache::ePerl
    </Files>
 
+which enables .iphtml files everywhere.
+
 Third, when you want to change the defaults of the ePerl parser, you also can
 add something like this to the end of the snippet above.
 
